@@ -8,29 +8,39 @@
 #include "enginebase_p.h"
 #include "knewstuffcore_debug.h"
 
+#include <QTimer>
+
 using namespace KNSCore;
 
 class KNSCore::ResultsStreamPrivate
 {
 public:
     QList<QSharedPointer<KNSCore::Provider>> providers;
-    EngineBase *engine;
+    EngineBase const *engine;
     Provider::SearchRequest request;
 };
 
 ResultsStream::ResultsStream(const Provider::SearchRequest &request, EngineBase *base)
-    : d(new ResultsStreamPrivate)
+    : d(new ResultsStreamPrivate{
+        .providers = base->d->providers.values(),
+        .engine = base,
+        .request = request,
+    })
 {
-    d->engine = base;
-    d->request = request;
-    d->providers = base->d->providers.values();
     auto finished = [this](const KNSCore::Provider::SearchRequest &request, const KNSCore::Entry::List &entries) {
-        d->providers.removeAll(static_cast<Provider *>(sender()));
+        if (request != d->request) {
+            return;
+        }
+
+        if (d->providers.removeAll(qobject_cast<Provider *>(sender())) <= 0) {
+            qCDebug(KNEWSTUFFCORE) << "Request finished twice, check your provider" << sender() << d->engine << entries.size();
+            return;
+        }
+
         if (entries.isEmpty() && d->providers.isEmpty()) {
             finish();
         }
-
-        if (request == d->request) {
+        if (!entries.isEmpty()) {
             Q_EMIT entriesFound(entries);
         }
     };
@@ -68,7 +78,9 @@ void ResultsStream::fetch()
 
     for (const QSharedPointer<KNSCore::Provider> &p : std::as_const(d->providers)) {
         if (p->isInitialized()) {
-            p->loadEntries(d->request);
+            QTimer::singleShot(0, this, [this, p] {
+                p->loadEntries(d->request);
+            });
         } else {
             connect(p.get(), &KNSCore::Provider::providerInitialized, this, [this, p] {
                 disconnect(p.get(), &KNSCore::Provider::providerInitialized, this, nullptr);
