@@ -10,7 +10,7 @@
 
 #include "staticxmlprovider_p.h"
 
-#include "xmlloader.h"
+#include "xmlloader_p.h"
 
 #include <QTimer>
 #include <knewstuffcore_debug.h>
@@ -62,7 +62,7 @@ bool StaticXmlProvider::setProviderXML(const QDomElement &xmldata)
     if (!iconurl.isValid()) {
         iconurl = QUrl::fromLocalFile(xmldata.attribute(QStringLiteral("icon")));
     }
-    mIcon = iconurl;
+    setIcon(iconurl);
 
     QDomNode n;
     QLocale::Language systemLanguage = QLocale::system().language();
@@ -72,7 +72,7 @@ bool StaticXmlProvider::setProviderXML(const QDomElement &xmldata)
         if (e.tagName() == QLatin1String("title")) {
             const QString lang{e.attribute(QLatin1String("lang"))};
             bool useThisTitle{false};
-            if (mName.isEmpty() && lang.isEmpty()) {
+            if (name().isEmpty() && lang.isEmpty()) {
                 // If we have no title as yet, and we've also got no language defined, this is the default
                 // and name we need to set it, even if we might override it later
                 useThisTitle = true;
@@ -83,7 +83,7 @@ bool StaticXmlProvider::setProviderXML(const QDomElement &xmldata)
                 }
             }
             if (useThisTitle) {
-                mName = e.text().trimmed();
+                setName(e.text().trimmed());
                 qCDebug(KNEWSTUFFCORE) << "add name for provider (" << this << "): " << e.text();
             }
             if (firstName.isEmpty()) {
@@ -91,9 +91,9 @@ bool StaticXmlProvider::setProviderXML(const QDomElement &xmldata)
             }
         }
     }
-    if (mName.isEmpty()) {
+    if (name().isEmpty()) {
         // Just a fallback, because those are quite nice to have...
-        mName = firstName;
+        setName(firstName);
     }
 
     // Validation
@@ -134,7 +134,7 @@ bool StaticXmlProvider::isInitialized() const
     return mInitialized;
 }
 
-void StaticXmlProvider::setCachedEntries(const KNSCore::EntryInternal::List &cachedEntries)
+void StaticXmlProvider::setCachedEntries(const KNSCore::Entry::List &cachedEntries)
 {
     qCDebug(KNEWSTUFFCORE) << "Set cached entries " << cachedEntries.size();
     mCachedEntries.append(cachedEntries);
@@ -146,7 +146,7 @@ void StaticXmlProvider::loadEntries(const KNSCore::Provider::SearchRequest &requ
 
     // static providers only have on page containing everything
     if (request.page > 0) {
-        Q_EMIT loadingFinished(request, EntryInternal::List());
+        Q_EMIT loadingFinished(request, Entry::List());
         return;
     }
 
@@ -155,7 +155,7 @@ void StaticXmlProvider::loadEntries(const KNSCore::Provider::SearchRequest &requ
         if (request.page == 0) {
             Q_EMIT loadingFinished(request, installedEntries());
         } else {
-            Q_EMIT loadingFinished(request, EntryInternal::List());
+            Q_EMIT loadingFinished(request, Entry::List());
         }
         return;
     }
@@ -167,8 +167,8 @@ void StaticXmlProvider::loadEntries(const KNSCore::Provider::SearchRequest &requ
         XmlLoader *loader = new XmlLoader(this);
         connect(loader, &XmlLoader::signalLoaded, this, &StaticXmlProvider::slotFeedFileLoaded);
         connect(loader, &XmlLoader::signalFailed, this, &StaticXmlProvider::slotFeedFailed);
-        loader->setProperty("filter", request.filter);
-        loader->setProperty("searchTerm", request.searchTerm);
+        loader->setFilter(request.filter);
+        loader->setSearchTerm(request.searchTerm);
 
         mFeedLoaders.insert(request.sortMode, loader);
 
@@ -211,28 +211,26 @@ void StaticXmlProvider::slotFeedFileLoaded(const QDomDocument &doc)
     }
 
     // load all the entries from the domdocument given
-    EntryInternal::List entries;
+    Entry::List entries;
     QDomElement element;
-    const Provider::Filter filter = loader->property("filter").value<Provider::Filter>();
-    const QString searchTerm = loader->property("searchTerm").toString();
 
     TagsFilterChecker checker(tagFilter());
     TagsFilterChecker downloadschecker(downloadTagFilter());
     element = doc.documentElement();
     QDomElement n;
     for (n = element.firstChildElement(); !n.isNull(); n = n.nextSiblingElement()) {
-        EntryInternal entry;
+        Entry entry;
         entry.setEntryXML(n.toElement());
-        entry.setStatus(KNS3::Entry::Downloadable);
+        entry.setStatus(KNSCore::Entry::Downloadable);
         entry.setProviderId(mId);
 
         int index = mCachedEntries.indexOf(entry);
         if (index >= 0) {
-            EntryInternal cacheEntry = mCachedEntries.takeAt(index);
+            Entry cacheEntry = mCachedEntries.takeAt(index);
             // check if updateable
-            if ((cacheEntry.status() == KNS3::Entry::Installed)
+            if ((cacheEntry.status() == KNSCore::Entry::Installed)
                 && ((cacheEntry.version() != entry.version()) || (cacheEntry.releaseDate() != entry.releaseDate()))) {
-                entry.setStatus(KNS3::Entry::Updateable);
+                entry.setStatus(KNSCore::Entry::Updateable);
                 entry.setUpdateVersion(entry.version());
                 entry.setVersion(cacheEntry.version());
                 entry.setUpdateReleaseDate(entry.releaseDate());
@@ -247,7 +245,7 @@ void StaticXmlProvider::slotFeedFileLoaded(const QDomDocument &doc)
             bool filterAcceptsDownloads = true;
             if (entry.downloadCount() > 0) {
                 const auto downloadInfoList = entry.downloadLinkInformationList();
-                for (const KNSCore::EntryInternal::DownloadLinkInformation &dli : downloadInfoList) {
+                for (const KNSCore::Entry::DownloadLinkInformation &dli : downloadInfoList) {
                     if (downloadschecker.filterAccepts(dli.tags)) {
                         filterAcceptsDownloads = true;
                         break;
@@ -258,17 +256,17 @@ void StaticXmlProvider::slotFeedFileLoaded(const QDomDocument &doc)
                 mCachedEntries.append(entry);
 
                 if (searchIncludesEntry(entry)) {
-                    switch (filter) {
+                    switch (loader->filter()) {
                     case Installed:
                         // This is dealth with in loadEntries separately
                         Q_UNREACHABLE();
                     case Updates:
-                        if (entry.status() == KNS3::Entry::Updateable) {
+                        if (entry.status() == KNSCore::Entry::Updateable) {
                             entries << entry;
                         }
                         break;
                     case ExactEntryId:
-                        if (entry.uniqueId() == searchTerm) {
+                        if (entry.uniqueId() == loader->searchTerm()) {
                             entries << entry;
                         }
                         break;
@@ -292,10 +290,10 @@ void StaticXmlProvider::slotFeedFailed()
     Q_EMIT loadingFailed(mCurrentRequest);
 }
 
-bool StaticXmlProvider::searchIncludesEntry(const KNSCore::EntryInternal &entry) const
+bool StaticXmlProvider::searchIncludesEntry(const KNSCore::Entry &entry) const
 {
     if (mCurrentRequest.filter == Updates) {
-        if (entry.status() != KNS3::Entry::Updateable) {
+        if (entry.status() != KNSCore::Entry::Updateable) {
             return false;
         }
     }
@@ -311,17 +309,17 @@ bool StaticXmlProvider::searchIncludesEntry(const KNSCore::EntryInternal &entry)
     return false;
 }
 
-void StaticXmlProvider::loadPayloadLink(const KNSCore::EntryInternal &entry, int)
+void StaticXmlProvider::loadPayloadLink(const KNSCore::Entry &entry, int)
 {
     qCDebug(KNEWSTUFFCORE) << "Payload: " << entry.payload();
     Q_EMIT payloadLinkLoaded(entry);
 }
 
-EntryInternal::List StaticXmlProvider::installedEntries() const
+Entry::List StaticXmlProvider::installedEntries() const
 {
-    EntryInternal::List entries;
-    for (const EntryInternal &entry : std::as_const(mCachedEntries)) {
-        if (entry.status() == KNS3::Entry::Installed || entry.status() == KNS3::Entry::Updateable) {
+    Entry::List entries;
+    for (const Entry &entry : std::as_const(mCachedEntries)) {
+        if (entry.status() == KNSCore::Entry::Installed || entry.status() == KNSCore::Entry::Updateable) {
             entries.append(entry);
         }
     }
